# Table of Contents

- [api-updates-graphql-error-handling](<./api-updates-graphql-error-handling.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [GraphQL API: Error Handling for Multiple Mutations Sent in a Single Request (July 28, 2025)](<./GraphQL-API-Error-Handling-for-Multiple-Mutations-Sent-in-a-Single-Request-July-28-2025.md>)
  - [Current Behavior](<./GraphQL-API-Error-Handling-for-Multiple-Mutations-Sent-in-a-Single-Request-July-28-2025/Current-Behavior.md>)
  - [What’s Changing](<./GraphQL-API-Error-Handling-for-Multiple-Mutations-Sent-in-a-Single-Request-July-28-2025/Whats-Changing.md>)
  - [What You Need to Do](<./GraphQL-API-Error-Handling-for-Multiple-Mutations-Sent-in-a-Single-Request-July-28-2025/What-You-Need-to-Do.md>)
  - [Example](<./GraphQL-API-Error-Handling-for-Multiple-Mutations-Sent-in-a-Single-Request-July-28-2025/Example.md>)
